Engine

Struct Engine 

pub struct Engine { /* private fields */ }
The state manager.

Implementations

Source

impl Engine

pub fn new() -> Self

pub fn push_state(&mut self, state: Rc<RefCell<dyn State>>)

Push a state onto the stack.

pub fn run(self)

Run the Engine, starting with the state on the top of the stack.

Since this function consumes the Engine, it cannot be reused.